@@ -1,7 +1,6 @@
 use salvo::extra::basic_auth::BasicAuthHandler;
 use salvo::extra::serve::StaticDir;
-use salvo::routing::Router;
-use salvo::Server;
+use salvo::prelude::*;
 
 #[tokio::main]
 async fn main() {
@@ -11,7 +10,10 @@ async fn main() {
     let auth_handler = BasicAuthHandler::new(validator);
 
     let router = Router::new()
-        .before(auth_handler)
+        .hoop(auth_handler)
         .get(StaticDir::new(vec!["examples/static/boy", "examples/static/girl"]));
-    Server::new(router).bind(([0, 0, 0, 0], 7878)).await;
+    Server::bind(&"127.0.0.1:7878".parse().unwrap())
+        .serve(Service::new(router))
+        .await
+        .unwrap();
 }
