@@ -12,10 +12,11 @@ async fn main() {
 
     let router = Router::new().get(hello_world);
     let catcher: Vec<Box<dyn Catcher>> = vec![Box::new(Handle404)];
-    Server::new(router)
-        .with_catchers(catcher)
-        .bind(([0, 0, 0, 0], 7878))
-        .await;
+    let service = Service::new(router).with_catchers(catcher);
+    Server::bind(&"127.0.0.1:7878".parse().unwrap())
+        .serve(service)
+        .await
+        .unwrap();
 }
 
 struct Handle404;
