@@ -1,4 +1,5 @@
 use salvo::prelude::*;
+use salvo::server::TcpListener;
 
 #[fn_handler]
 async fn hello_world() -> &'static str {
@@ -31,5 +32,11 @@ async fn main() {
         .push(Router::with_path("hello2").get(hello_world2))
         .push(Router::with_path("hello3").get(hello_world3))
         .push(Router::with_path("hello4").get(hello_world4));
-    Server::new(router).bind(([0, 0, 0, 0], 7878)).await;
+    // Server::bind(&"127.0.0.1:7878".parse().unwrap())
+    //     .serve(Service::new(router))
+    //     .await.unwrap();
+    Server::builder(TcpListener::bind(([0, 0, 0, 0], 7878)).unwrap())
+        .serve(Service::new(router))
+        .await
+        .unwrap();
 }
