@@ -16,8 +16,9 @@ async fn main() {
     let router1 = Router::new().get(hello_world1);
     let router2 = Router::new().get(hello_world2);
 
-    tokio::join!(
-        Server::new(router1).bind(([0, 0, 0, 0], 7878)),
-        Server::new(router2).bind(([0, 0, 0, 0], 6868))
-    );
+    tokio::try_join!(
+        Server::bind(&"127.0.0.1:7979".parse().unwrap()).serve(Service::new(router1)),
+        Server::bind(&"127.0.0.1:7878".parse().unwrap()).serve(Service::new(router2))
+    )
+    .unwrap();
 }
