@@ -9,7 +9,7 @@ async fn main() {
         .get(index)
         .push(
             Router::with_path("users")
-                .before(auth)
+                .hoop(auth)
                 .post(create_user)
                 .push(Router::with_path(r"<id:num>").post(update_user).delete(delete_user)),
         )
@@ -33,7 +33,10 @@ async fn main() {
             }
         });
 
-    Server::new(router).bind(([0, 0, 0, 0], 7878)).await;
+    Server::bind(&"127.0.0.1:7878".parse().unwrap())
+        .serve(Service::new(router))
+        .await
+        .unwrap();
 }
 
 #[fn_handler]
