@@ -35,12 +35,15 @@ async fn main() {
         .get(index)
         .push(
             Router::new()
-                .before(max_size(1024 * 1024 * 10))
+                .hoop(max_size(1024 * 1024 * 10))
                 .path("limited")
                 .post(upload),
         )
         .push(Router::with_path("unlimit").post(upload));
-    Server::new(router).bind(([0, 0, 0, 0], 7878)).await;
+    Server::bind(&"127.0.0.1:7878".parse().unwrap())
+        .serve(Service::new(router))
+        .await
+        .unwrap();
 }
 
 static INDEX_HTML: &str = r#"<!DOCTYPE html>
