@@ -35,7 +35,10 @@ async fn main() {
 
     create_dir_all("temp").unwrap();
     let router = Router::new().get(index).post(upload);
-    Server::new(router).bind(([0, 0, 0, 0], 7878)).await;
+    Server::bind(&"127.0.0.1:7878".parse().unwrap())
+        .serve(Service::new(router))
+        .await
+        .unwrap();
 }
 
 static INDEX_HTML: &str = r#"<!DOCTYPE html>
