@@ -25,5 +25,8 @@ async fn connect(req: &mut Request, res: &mut Response) -> Result<(), HttpError>
 async fn main() {
     tracing_subscriber::fmt().init();
     let router = Router::new().handle(connect);
-    Server::new(router).bind(([0, 0, 0, 0], 7878)).await;
+    Server::bind(&"127.0.0.1:7878".parse().unwrap())
+        .serve(Service::new(router))
+        .await
+        .unwrap();
 }
