@@ -25,7 +25,10 @@ async fn main() {
     let router = Router::new()
         .handle(index)
         .push(Router::with_path("chat").handle(user_connected));
-    Server::new(router).bind(([0, 0, 0, 0], 7878)).await;
+    Server::bind(&"127.0.0.1:7878".parse().unwrap())
+        .serve(Service::new(router))
+        .await
+        .unwrap();
 }
 
 #[fn_handler]
